@@ -4,8 +4,7 @@ use strict;
 use warnings;
 use Moose;
 use overload '""' => sub {
-    require Carp;
-    Carp::longmess( shift->message );
+    shift->message;
   },
   fallback => 1;
 
